@@ -552,6 +552,8 @@ class BinCopyWriter:
         self.insert_count = 0
         self.session_id = session_id
         self.tbl_uuid = str(uuid1()).replace("-", '_')
+
+    def make_query(self):
         self.cmd = f"""
             CREATE UNLOGGED TABLE IF NOT EXISTS "{self.tbl_uuid}"
                 (LIKE event_{self.session_id} INCLUDING DEFAULTS);
@@ -561,7 +563,7 @@ class BinCopyWriter:
             CREATE INDEX tmp_idx on "{self.tbl_uuid}" (id, updates DESC);
 
             INSERT INTO event_{self.session_id}
-            SELECT * FROM "{tbl_uuid}";
+            SELECT * FROM "{self.tbl_uuid}";
 
             INSERT INTO object (
                 id, session_id, last_seen, alive, lat, lon, alt, roll, pitch,
@@ -649,7 +651,7 @@ class BinCopyWriter:
         if not force and self.batch_size > self.insert_count:
             LOG.debug("Not enough data for insert....")
             return
-
+        self.make_query()
         LOG.debug(f'Inserting {self.insert_count} records...')
         self.insert.write(self.copy_trailer)
         self.insert.seek(0)
@@ -689,6 +691,8 @@ async def consumer(host: str,
 
             if obj[0:1] == b"#":
                 sock.update_time(obj)
+                if not copy_writer.session_id:
+                    copy_writer.session_id = sock.session_id
                 await copy_writer.insert_data()
 
                 runtime = time.time() - init_time
@@ -717,6 +721,7 @@ async def consumer(host: str,
                 copy_writer.add_data(obj)
 
             if max_iters and max_iters < lines_read:
+                copy_writer.session_id = sock.session_id
                 await copy_writer.insert_data()
                 LOG.info(f"Max iters reached: {max_iters}...returning...")
                 raise MaxIterationsException
